@@ -1,6 +1,6 @@
 package Image::Info::SVG;
 
-$VERSION = '1.02';
+$VERSION = '1.03';
 
 use strict;
 no strict 'refs';
@@ -129,6 +129,14 @@ The URI of the DTD the image conforms to.
 
 =back
 
+=head1 METHODS
+
+=head2 process_file()
+    
+	$info->process_file($source, $options);
+
+Processes one file and sets the found info fields in the C<$info> object.
+
 =head1 FILES
 
 This module requires L<XML::Simple>
